@@ -100,14 +100,16 @@ public class Commandline
     /**
      * @deprecated Use {@link org.codehaus.plexus.util.Os} class instead.
      */
+    @Deprecated
     protected static final String OS_NAME = "os.name";
 
     /**
      * @deprecated Use {@link org.codehaus.plexus.util.Os} class instead.
      */
+    @Deprecated
     protected static final String WINDOWS = "Windows";
 
-    protected Vector<Arg> arguments = new Vector<Arg>();
+    protected Vector<Arg> arguments = new Vector<>();
 
     // protected Vector envVars = new Vector();
     // synchronized added to preserve synchronize of Vector class
@@ -120,19 +122,22 @@ public class Commandline
     /**
      * @deprecated Use {@link Commandline#setExecutable(String)} instead.
      */
+    @Deprecated
     protected String executable;
 
     /**
      * @deprecated Use {@link Commandline#setWorkingDirectory(File)} or {@link Commandline#setWorkingDirectory(String)}
      *             instead.
      */
+    @Deprecated
     private File workingDir;
 
     /**
      * Create a new command line object. Shell is autodetected from operating system Shell usage is only desirable when
      * generating code for remote execution.
      *
-     * @param toProcess
+     * @param toProcess sh to process
+     * @param shell Shell to use
      */
     public Commandline( String toProcess, Shell shell )
     {
@@ -160,6 +165,7 @@ public class Commandline
     /**
      * Create a new command line object. Shell is autodetected from operating system Shell usage is only desirable when
      * generating code for remote execution.
+     * @param shell the Shell
      */
     public Commandline( Shell shell )
     {
@@ -169,7 +175,7 @@ public class Commandline
     /**
      * Create a new command line object, given a command following POSIX sh quoting rules
      *
-     * @param toProcess
+     * @param toProcess the process
      */
     public Commandline( String toProcess )
     {
@@ -235,7 +241,7 @@ public class Commandline
         }
 
         /**
-         * <p>Return the number of arguments that preceded this marker.</p>
+         * @return the number of arguments that preceded this marker.
          * 
          * <p>The name of the executable - if set - is counted as the very first argument.</p>
          */
@@ -246,7 +252,7 @@ public class Commandline
                 realPos = ( getLiteralExecutable() == null ? 0 : 1 );
                 for ( int i = 0; i < position; i++ )
                 {
-                    Arg arg = (Arg) arguments.elementAt( i );
+                    Arg arg = arguments.elementAt( i );
                     realPos += arg.getParts().length;
                 }
             }
@@ -289,6 +295,7 @@ public class Commandline
      * @see #createArgument(boolean)
      * @deprecated Use {@link Commandline#createArg()} instead
      */
+    @Deprecated
     public Argument createArgument()
     {
         return this.createArgument( false );
@@ -302,7 +309,9 @@ public class Commandline
      * @param insertAtStart if true, the argument is inserted at the beginning of the list of args, otherwise it is
      *            appended.
      * @deprecated Use {@link Commandline#createArg(boolean)} instead
+     * @return Argument the argument Object
      */
+    @Deprecated
     public Argument createArgument( boolean insertAtStart )
     {
         Argument argument = new Argument();
@@ -332,7 +341,7 @@ public class Commandline
     }
 
     /**
-     * <p>Creates an argument object and adds it to our list of args.</p>
+     * @return Creates an argument object and adds it to our list of args.
      * 
      * <p>Each commandline object has at most one instance of the argument class.</p>
      *
@@ -354,8 +363,7 @@ public class Commandline
     }
 
     /**
-     * Adds an argument object to our list of args.
-     *
+     * @param argument the argument
      * @see #addArg(Arg,boolean)
      */
     public void addArg( Arg argument )
@@ -365,7 +373,7 @@ public class Commandline
 
     /**
      * Adds an argument object to our list of args.
-     *
+     * @param argument the argument
      * @param insertAtStart if true, the argument is inserted at the beginning of the list of args, otherwise it is
      *            appended.
      */
@@ -383,6 +391,7 @@ public class Commandline
 
     /**
      * Sets the executable to run.
+     * @param executable the executable
      */
     public void setExecutable( String executable )
     {
@@ -426,6 +435,8 @@ public class Commandline
 
     /**
      * Add an environment variable
+     * @param name name
+     * @param value value
      */
     public void addEnvironment( String name, String value )
     {
@@ -435,6 +446,7 @@ public class Commandline
 
     /**
      * Add system environment variables
+     * @throws Exception if error
      */
     public void addSystemEnvironment()
         throws Exception
@@ -452,7 +464,8 @@ public class Commandline
     }
 
     /**
-     * Return the list of environment variables
+     * @return String[] Return the list of environment variables
+     * @throws CommandLineException if error
      */
     public String[] getEnvironmentVariables()
         throws CommandLineException
@@ -478,8 +491,8 @@ public class Commandline
     }
 
     /**
-     * Returns the executable and all defined arguments.<br>
-     * For Windows Family, {@link Commandline#getShellCommandline()} is returned
+     * @return Returns the executable and all defined arguments.
+     *      For Windows Family, {@link Commandline#getShellCommandline()} is returned
      */
     public String[] getCommandline()
     {
@@ -492,8 +505,8 @@ public class Commandline
     }
 
     /**
-     * Returns the executable and all defined arguments.<br>
-     * 
+     * Returns the executable and all defined arguments.
+     * @return the command line as array not escaped neither quoted
      */
     public String[] getRawCommandline()
     {
@@ -513,21 +526,22 @@ public class Commandline
 	/**
      * Returns the shell, executable and all defined arguments. Shell usage is only desirable when generating code for
      * remote execution.
+     * @return the command line as array
      */
     public String[] getShellCommandline()
     {
         // TODO: Provided only for backward compat. with <= 1.4
         verifyShellState();
 
-        return (String[]) getShell().getShellCommandLine( getArguments() ).toArray( new String[0] );
+        return getShell().getShellCommandLine( getArguments() ).toArray( new String[0] );
     }
 
     /**
-     * Returns all arguments defined by <code>addLine</code>, <code>addValue</code> or the argument object.
+     * @return Returns all arguments defined by <code>addLine</code>, <code>addValue</code> or the argument object.
      */
     public String[] getArguments()
     {
-        Vector<String> result = new Vector<String>( arguments.size() * 2 );
+        Vector<String> result = new Vector<>( arguments.size() * 2 );
         for ( int i = 0; i < arguments.size(); i++ )
         {
             Arg arg = arguments.elementAt( i );
@@ -546,6 +560,7 @@ public class Commandline
         return res;
     }
 
+    @Override
     public String toString()
     {
         return StringUtils.join( getShellCommandline(), " " );
@@ -556,6 +571,7 @@ public class Commandline
         return getCommandline().length;
     }
 
+    @Override
     public Object clone()
     {
         Commandline c = new Commandline( (Shell) shell.clone() );
@@ -586,11 +602,11 @@ public class Commandline
     }
 
     /**
-     * <p>Return a marker.</p>
-     * 
+     *
      * <p>This marker can be used to locate a position on the commandline - to insert something for example - when all
      * parameters have been set.
      * </p>
+     * @return Return a marker.
      */
     public Marker createMarker()
     {
@@ -599,6 +615,7 @@ public class Commandline
 
     /**
      * Sets execution directory.
+     * @param path the working directory as String
      */
     public void setWorkingDirectory( String path )
     {
@@ -608,6 +625,7 @@ public class Commandline
 
     /**
      * Sets execution directory.
+     * @param workingDirectory the File used as working directory
      */
     public void setWorkingDirectory( File workingDirectory )
     {
@@ -629,6 +647,8 @@ public class Commandline
 
     /**
      * Executes the command.
+     * @return the Process
+     * @throws CommandLineException if error
      */
     public Process execute()
         throws CommandLineException
@@ -677,6 +697,7 @@ public class Commandline
     /**
      * @deprecated Remove once backward compat with plexus-utils <= 1.4 is no longer a consideration
      */
+    @Deprecated
     private void verifyShellState()
     {
         if ( shell.getWorkingDirectory() == null )
@@ -700,7 +721,7 @@ public class Commandline
      * Allows to set the shell to be used in this command line. Shell usage is only desirable when generating code for
      * remote execution.
      *
-     * @param shell
+     * @param shell Shell to use
      * @since 1.2
      */
     public void setShell( Shell shell )
@@ -713,6 +734,7 @@ public class Commandline
      * execution.
      * 
      * @since 1.2
+     * @return the Shell
      */
     public Shell getShell()
     {
@@ -720,8 +742,12 @@ public class Commandline
     }
 
     /**
+     * @param toProcess the process
+     * @return the command line arguments
+     * @throws Exception if error happen
      * @deprecated Use {@link CommandLineUtils#translateCommandline(String)} instead.
      */
+    @Deprecated
     public static String[] translateCommandline( String toProcess )
         throws Exception
     {
@@ -729,8 +755,12 @@ public class Commandline
     }
 
     /**
+     * @param argument the argument
+     * @return the quote arg
+     * @throws CommandLineException if error happen
      * @deprecated Use {@link CommandLineUtils#quote(String)} instead.
      */
+    @Deprecated
     public static String quoteArgument( String argument )
         throws CommandLineException
     {
@@ -739,7 +769,10 @@ public class Commandline
 
     /**
      * @deprecated Use {@link CommandLineUtils#toString(String[])} instead.
+     * @param line the lines
+     * @return lines as single String
      */
+    @Deprecated
     public static String toString( String[] line )
     {
         return CommandLineUtils.toString( line );
@@ -754,6 +787,7 @@ public class Commandline
          * (non-Javadoc)
          * @see org.codehaus.plexus.util.cli.Argument#setValue(java.lang.String)
          */
+        @Override
         public void setValue( String value )
         {
             if ( value != null )
@@ -766,6 +800,7 @@ public class Commandline
          * (non-Javadoc)
          * @see org.codehaus.plexus.util.cli.Argument#setLine(java.lang.String)
          */
+        @Override
         public void setLine( String line )
         {
             if ( line == null )
@@ -786,6 +821,7 @@ public class Commandline
          * (non-Javadoc)
          * @see org.codehaus.plexus.util.cli.Argument#setFile(java.io.File)
          */
+        @Override
         public void setFile( File value )
         {
             parts = new String[] { value.getAbsolutePath() };
@@ -795,6 +831,7 @@ public class Commandline
          * (non-Javadoc)
          * @see org.codehaus.plexus.util.cli.Argument#getParts()
          */
+        @Override
         public String[] getParts()
         {
             return parts;
