@@ -16,13 +16,13 @@ package org.codehaus.plexus.util.xml;
  * limitations under the License.
  */
 
+import org.codehaus.plexus.util.StringUtils;
 import org.codehaus.plexus.util.xml.pull.XmlSerializer;
 
 import java.io.IOException;
 import java.io.Serializable;
 import java.io.StringWriter;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -31,7 +31,7 @@ import java.util.ListIterator;
 import java.util.Map;
 
 /**
- * @version $Id$ NOTE: remove all the util code in here when separated, this class should be pure data.
+ *  NOTE: remove all the util code in here when separated, this class should be pure data.
  */
 public class Xpp3Dom
     implements Serializable
@@ -76,6 +76,8 @@ public class Xpp3Dom
 
     public static final String SELF_COMBINATION_MERGE = "merge";
 
+    public static final String SELF_COMBINATION_REMOVE = "remove";
+
     /**
      * This default mode for combining a DOM node during merge means that where element names match, the process will
      * try to merge the element attributes and values, rather than overriding the recessive element completely with the
@@ -87,11 +89,13 @@ public class Xpp3Dom
     public Xpp3Dom( String name )
     {
         this.name = name;
-        childList = new ArrayList<Xpp3Dom>();
+        childList = new ArrayList<>();
     }
 
     /**
      * @since 3.2.0
+     * @param inputLocation The input location.
+     * @param name The name of the Dom.
      */
     public Xpp3Dom( String name, Object inputLocation )
     {
@@ -101,6 +105,7 @@ public class Xpp3Dom
 
     /**
      * Copy constructor.
+     * @param src The source Dom.
      */
     public Xpp3Dom( Xpp3Dom src )
     {
@@ -109,6 +114,8 @@ public class Xpp3Dom
 
     /**
      * Copy constructor with alternative name.
+     * @param src The source Dom.
+     * @param name The name of the Dom.
      */
     public Xpp3Dom( Xpp3Dom src, String name )
     {
@@ -177,6 +184,17 @@ public class Xpp3Dom
         return ( null != attributes ) ? attributes.get( name ) : null;
     }
 
+    /**
+     *
+     * @param name name of the attribute to be removed
+     * @return <code>true</code> if the attribute has been removed
+     * @since 3.4.0
+     */
+    public boolean removeAttribute( String name )
+    {
+        return StringUtils.isEmpty( name ) ? false: attributes.remove( name ) == null;
+    }
+
     /**
      * Set the attribute value
      * 
@@ -301,6 +319,13 @@ public class Xpp3Dom
         child.setParent( null );
     }
 
+    public void removeChild( Xpp3Dom child )
+    {
+        childList.remove( child );
+        // In case of any dangling references
+        child.setParent( null );
+    }
+
     // ----------------------------------------------------------------------
     // Parent handling
     // ----------------------------------------------------------------------
@@ -321,6 +346,7 @@ public class Xpp3Dom
 
     /**
      * @since 3.2.0
+     * @return input location
      */
     public Object getInputLocation()
     {
@@ -329,6 +355,7 @@ public class Xpp3Dom
 
     /**
      * @since 3.2.0
+     * @param inputLocation input location to set
      */
     public void setInputLocation( Object inputLocation )
     {
@@ -418,7 +445,7 @@ public class Xpp3Dom
             {
                 for ( String attr : recessive.attributes.keySet() )
                 {
-                    if ( isEmpty( dominant.getAttribute( attr ) ) )
+                    if ( isEmpty( dominant.getAttribute( attr ) ) && !SELF_COMBINATION_MODE_ATTRIBUTE.equals( attr ) )
                     {
                         dominant.setAttribute( attr, recessive.getAttribute( attr ) );
                     }
@@ -489,7 +516,17 @@ public class Xpp3Dom
                         else if ( it.hasNext() )
                         {
                             Xpp3Dom dominantChild = it.next();
-                            mergeIntoXpp3Dom( dominantChild, recessiveChild, childMergeOverride );
+
+                            String dominantChildCombinationMode =
+                                dominantChild.getAttribute( SELF_COMBINATION_MODE_ATTRIBUTE );
+                            if ( SELF_COMBINATION_REMOVE.equals( dominantChildCombinationMode ) )
+                            {
+                                dominant.removeChild( dominantChild );
+                            }
+                            else
+                            {
+                                mergeIntoXpp3Dom( dominantChild, recessiveChild, childMergeOverride );
+                            }
                         }
                     }
                 }
@@ -506,6 +543,7 @@ public class Xpp3Dom
      * @param recessive The recessive DOM, which will be merged into the dominant DOM
      * @param childMergeOverride Overrides attribute flags to force merging or appending of child elements into the
      *            dominant DOM
+     * @return merged DOM
      */
     public static Xpp3Dom mergeXpp3Dom( Xpp3Dom dominant, Xpp3Dom recessive, Boolean childMergeOverride )
     {
@@ -525,6 +563,7 @@ public class Xpp3Dom
      * @see #SELF_COMBINATION_MODE_ATTRIBUTE
      * @param dominant The dominant DOM into which the recessive value/attributes/children will be merged
      * @param recessive The recessive DOM, which will be merged into the dominant DOM
+     * @return merged DOM
      */
     public static Xpp3Dom mergeXpp3Dom( Xpp3Dom dominant, Xpp3Dom recessive )
     {
@@ -540,6 +579,7 @@ public class Xpp3Dom
     // Standard object handling
     // ----------------------------------------------------------------------
 
+    @Override
     public boolean equals( Object obj )
     {
         if ( obj == this )
@@ -576,6 +616,7 @@ public class Xpp3Dom
         }
     }
 
+    @Override
     public int hashCode()
     {
         int result = 17;
@@ -586,6 +627,7 @@ public class Xpp3Dom
         return result;
     }
 
+    @Override
     public String toString()
     {
         // TODO: WARNING! Later versions of plexus-utils psit out an <?xml ?> header due to thinking this is a new
